import { FactoryProvider } from '@angular/core';
import { Observable } from 'rxjs';
import { HttpUtility } from 'rl-http';
import { IArrayUtility, ArrayUtility } from '../../array/array.service';
import { IBaseResourceParams } from '../resourceBuilder/resourceBuilder.service';
export interface IBaseDomainObject {
    id?: number;
}
export interface IDataService<TDataType extends IBaseDomainObject, TSearchParams> {
    getList(params?: TSearchParams): Observable<TDataType[]>;
    getDetail(id: number): Observable<TDataType>;
    create(domainObject: TDataType): Observable<TDataType>;
    update(domainObject: TDataType): Observable<TDataType>;
    delete(domainObject: TDataType): Observable<void>;
    version(versionNumber: number): DataService<TDataType, TSearchParams>;
    useMock: boolean;
    logRequests: boolean;
}
export interface ISearchDataService<TDataType extends IBaseDomainObject, TSearchParams, TResultType> {
    getList(params?: TSearchParams): Observable<TResultType>;
}
export declare class DataService<TDataType extends IBaseDomainObject, TSearchParams> implements IDataService<TDataType, TSearchParams> {
    private behavior;
    private useDeepSearch;
    protected mockData: TDataType[];
    protected array: IArrayUtility;
    endpoint: string;
    url: string;
    useMock: boolean;
    logRequests: boolean;
    constructor(http: HttpUtility, array: ArrayUtility, options: IBaseResourceParams<TDataType>);
    private getItemEndpoint(id);
    getList(params: TSearchParams): Observable<TDataType[]>;
    getDetail(id: number): Observable<TDataType>;
    create(domainObject: TDataType): Observable<TDataType>;
    update(domainObject: TDataType): Observable<TDataType>;
    delete(domainObject: TDataType): Observable<void>;
    version(versionNumber: number): DataService<TDataType, TSearchParams>;
}
export interface IDataServiceFactory {
    getInstance<TDataType extends IBaseDomainObject, TSearchParams>(options: IBaseResourceParams<TDataType>): IDataService<TDataType, TSearchParams>;
}
export declare class DataServiceFactory {
    private http;
    private array;
    constructor(http: HttpUtility, array: ArrayUtility);
    getInstance<TDataType extends IBaseDomainObject, TSearchParams>(options: IBaseResourceParams<TDataType>): IDataService<TDataType, TSearchParams>;
}
export declare function DataServiceProvider(options: IBaseResourceParams<any>): FactoryProvider;
