import { ErrorHandler } from '@angular/core';
import { NotificationService } from '../notification/notification.service';
import { RedirectService } from '../redirect/redirect.service';
export declare enum HttpStatusCode {
    cancelledRequest = -1,
    badRequest = 400,
    unauthorized = 401,
    forbidden = 403,
    invalidUrl = 404,
    timeout = 408,
    internalServerError = 500,
    gone = 410,
}
export interface IRejection {
    status: HttpStatusCode;
    data?: any;
}
export interface IErrorHandlerService {
    httpResponseError(rejection: IRejection): void;
}
export interface IErrorMessages {
    badRequestError: string;
    forbiddenError: string;
    invalidUrlError: string;
    timeoutError: string;
    internalServerError: string;
    defaultError: string;
    goneError: string;
}
export interface ILoginUrlSettings {
    loginUrl: string;
    returnUrlParam: string;
}
export declare class DefaultErrors implements IErrorMessages {
    badRequestError: string;
    forbiddenError: string;
    invalidUrlError: string;
    timeoutError: string;
    internalServerError: string;
    defaultError: string;
    goneError: string;
}
export declare class DefaultLoginUrlSettings implements ILoginUrlSettings {
    loginUrl: string;
    returnUrlParam: string;
}
export declare class ErrorHandlerService implements IErrorHandlerService {
    private redirect;
    private errorHandler;
    private notification;
    private loginSettings;
    private errorMessages;
    constructor(redirect: RedirectService, errorHandler: ErrorHandler, notification: NotificationService, errorMessages: DefaultErrors, loginSettings: DefaultLoginUrlSettings);
    httpResponseError(rejection: IRejection): void;
    private badRequestError(rejection);
    private loggedOutError();
    private insufficientPermissionsError();
    private invalidUrlError();
    private timeoutError();
    private systemError();
    private goneError();
}
